/* file: data/static/games/qpig/farm.css */

.qpig-garden {
    font-family: monospace;
    background: #7ec87e;
    border: 2px solid #2b7a2b;
    padding: 8px;
    margin: 0 auto;
    display: inline-block;
}

.qpig-garden .qpig-buttons {
    display: flex;
    gap: 8px;
    margin: 1em 0;
}

.qpig-garden button {
    padding: 6px 12px;
    border: 1px solid #333;
    background: #d6f5d6;
    cursor: pointer;
    color: #000;
}

.qpig-garden #qpig-canvas {
    display: block;
    margin: 8px auto;
    image-rendering: pixelated;
    border: 1px solid #333;
}

.qpig-garden .qpig-warning {

    margin-top: 1em;
    color: #a00;
}
